@@ -4,7 +4,6 @@ from dataclasses import dataclass, field
 from flag_engine.environments.integrations.models import IntegrationModel
 from flag_engine.features.models import FeatureStateModel
 from flag_engine.projects.models import ProjectModel
-from flag_engine.utils.exceptions import FeatureStateNotFound
 
 
 @dataclass
@@ -17,12 +16,3 @@ class EnvironmentModel:
     segment_config: IntegrationModel = None
     mixpanel_config: IntegrationModel = None
     heap_config: IntegrationModel = None
-
-    def get_feature_state(self, feature_name: str) -> FeatureStateModel:
-        try:
-            return next(
-                filter(lambda f: f.feature.name == feature_name, self.feature_states)
-            )
-
-        except StopIteration:
-            raise FeatureStateNotFound()
