@@ -21,13 +21,15 @@ class FeatureModel:
 @dataclass
 class MultivariateFeatureOptionModel:
     value: typing.Any
+    id: int = None
 
 
 @dataclass
 class MultivariateFeatureStateValueModel:
-    id: int
     multivariate_feature_option: MultivariateFeatureOptionModel
     percentage_allocation: float
+    id: int = None
+    mv_fs_value_uuid: str = field(default_factory=uuid.uuid4)
 
 
 @dataclass
@@ -65,7 +67,8 @@ class FeatureStateModel:
         # percentage value.
         start_percentage = 0
         for mv_value in sorted(
-            self.multivariate_feature_state_values, key=lambda v: v.id
+            self.multivariate_feature_state_values,
+            key=lambda v: v.id or v.mv_fs_value_uuid,
         ):
             limit = mv_value.percentage_allocation + start_percentage
             if start_percentage <= percentage_value < limit:
